#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 GraphSCC
version:              1.0.4
visibility:           public
id:                   GraphSCC-1.0.4-Kc19hgNPBZz9hITg1zO3Dh
key:                  GraphSCC-1.0.4-Kc19hgNPBZz9hITg1zO3Dh
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
synopsis:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.

description:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.

category:             Algorithms
abi:                  d86b1e83769dc905748bb26fb5834dae
exposed:              True
exposed-modules:      Data.Graph.SCC
hidden-modules:       Data.Graph.ArraySCC
import-dirs:          /usr/lib/ghc-8.10.5/site-local/GraphSCC-1.0.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/GraphSCC-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/GraphSCC-1.0.4
hs-libraries:         HSGraphSCC-1.0.4-Kc19hgNPBZz9hITg1zO3Dh
depends:              array-0.5.4.0 base-4.14.2.0 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-graphscc/html/GraphSCC.haddock
haddock-html:         /usr/share/doc/haskell-graphscc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

